==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/RadialLineSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { AnchoredRadialSeriesDescription } from "./AnchoredRadialSeriesDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var RadialLineSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(RadialLineSeriesDescription, _super);
    function RadialLineSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.el = null;
        return _this;
    }
    RadialLineSeriesDescription.prototype.get_type = function () {
        return "RadialLineSeries";
    };
    Object.defineProperty(RadialLineSeriesDescription.prototype, "unknownValuePlotting", {
        get: function () {
            return this.el;
        },
        set: function (a) {
            this.el = a;
            this.e("UnknownValuePlotting");
        },
        enumerable: true,
        configurable: true
    });
    RadialLineSeriesDescription.$t = markType(RadialLineSeriesDescription, 'RadialLineSeriesDescription', AnchoredRadialSeriesDescription.$);
    return RadialLineSeriesDescription;
}(AnchoredRadialSeriesDescription));
export { RadialLineSeriesDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/RadialLineSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { AnchoredRadialSeriesDescription } from "./AnchoredRadialSeriesDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var RadialLineSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialLineSeriesDescription, _super);
    function RadialLineSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.ht = null;
        return _this;
    }
    RadialLineSeriesDescription.prototype.get_type = function () {
        return "RadialLineSeries";
    };
    Object.defineProperty(RadialLineSeriesDescription.prototype, "unknownValuePlotting", {
        get: function () {
            return this.ht;
        },
        set: function (a) {
            this.ht = a;
            this.g("UnknownValuePlotting");
        },
        enumerable: false,
        configurable: true
    });
    RadialLineSeriesDescription.$t = markType(RadialLineSeriesDescription, 'RadialLineSeriesDescription', AnchoredRadialSeriesDescription.$);
    return RadialLineSeriesDescription;
}(AnchoredRadialSeriesDescription));
export { RadialLineSeriesDescription };
